Toast class

Constructors

Toast({String? launch, ToastDuration? duration, DateTime? displayTimestamp, ToastScenario? scenario, bool? useButtonStyle, List<ToastChild> children = const []})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toXmlString({bool pretty = false}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited