WinToast class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all notifications.
dismiss({required String tag, required String group}) Future<void>
Clear a notification by tag, group.
initialize({required String aumId, required String displayName, required String iconPath, required String clsid}) Future<bool>
Initialize the WinToast.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setActivatedCallback(ToastActivatedCallback? callback) → void
setDismissedCallback(ToastDismissedCallback? callback) → void
showCustomToast({required String xml, String? tag, String? group}) Future<void>
Show a toast notification. xml is the raw XML content of win toast. schema can be found here: https://learn.microsoft.com/en-us/uwp/schemas/tiles/toastschema/schema-root
showToast({required Toast toast, String? tag, String? group}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

instance() WinToast